# API

## Preprocessing

```{eval-rst}
.. module:: pycea.pp
.. currentmodule:: pycea

.. autosummary::
    :toctree: generated

    pp.add_depth
```

## Tools

```{eval-rst}
.. module:: pycea.tl
.. currentmodule:: pycea

.. autosummary::
    :toctree: generated

    tl.ancestral_states
    tl.autocorr
    tl.clades
    tl.compare_distance
    tl.distance
    tl.neighbor_distance
    tl.sort
    tl.tree_distance
    tl.tree_neighbors
```

## Plotting

```{eval-rst}
.. module:: pycea.pl
.. currentmodule:: pycea

.. autosummary::
    :toctree: generated

    pl.tree
    pl.branches
    pl.nodes
    pl.annotation
```

## Getting elements

```{eval-rst}
.. module:: pycea.get
.. currentmodule:: pycea

.. autosummary::
    :toctree: generated

    get.palette
```

## Datasets

```{eval-rst}
.. module:: pycea.datasets
.. currentmodule:: pycea

.. autosummary::
    :toctree: generated

    datasets.packer19
    datasets.yang22
    datasets.koblan25
```
